==> mpc-1.5.0.zip: org/eclipse/epp/internal/mpc/ui/wizards/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2010 The Eclipse Foundation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     The Eclipse Foundation - initial API and implementation
 *******************************************************************************/
package org.eclipse.epp.internal.mpc.ui.wizards;

import org.eclipse.osgi.util.NLS;

class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.epp.internal.mpc.ui.wizards.messages"; //$NON-NLS-1$

	public static String BrowseCatalogItem_browseMoreLink;

	public static String BrowseCatalogItem_browseMoreLinkNoCount;

	public static String BrowseCatalogItem_cannotOpenBrowser;

	public static String BrowseCatalogItem_openUrlBrowser;

	public static String CatalogSelectionPage_selectASolutionCatalog;

	public static String CatalogSelectionPage_solutionMarketplaceCatalog;

	public static String CatalogSwitcher_downloadCatalogImage;

	public static String CatalogSwitcher_Header;

	public static String CatalogSwitcher_retrieveMetaData;

	public static String DiscoveryItem_AlreadyInstalled;

	public static String DiscoveryItem_byProviderLicense;

	public static String DiscoveryItem_cannotRenderImage_reason;

	public static String DiscoveryItem_Compact_Number;

	public static String DiscoveryItem_FavoriteActionFailed;

	public static String DiscoveryItem_Favorited_Times;

	public static String DiscoveryItem_installInstructions;

	public static String DiscoveryItem_installInstructionsTooltip;

	public static String DiscoveryItem_Installs;

	public static String DiscoveryItem_missingNodeUrl;

	public static String DiscoveryItem_More_Info;

	public static String DiscoveryItem_Promotion_Display;

	public static String DiscoveryItem_Promotion_Marker;

	public static String DiscoveryItem_Share;

	public static String DiscoveryItem_showOverview;

	public static String DiscoveryItem_truncatedTextSuffix;

	public static String DiscoveryItem_Unknown_Favorites;

	public static String DiscoveryItem_Unknown_Installs;

	public static String DiscoveryItem_UnknownProvider;

	public static String DiscoveryItem_UnnamedSolution;

	public static String FavoritesViewer_searchInputDescription;

	public static String FavoritesViewer_searchLabel;

	public static String FeatureSelectionWizardPage_confirmSelectedFeatures;

	public static String FeatureSelectionWizardPage_confirmSelectedFeatures_description;

	public static String FeatureSelectionWizardPage_details;

	public static String FeatureSelectionWizardPage_detailsUnavailable;

	public static String FeatureSelectionWizardPage_Install_Pending;

	public static String FeatureSelectionWizardPage_noneAvailable;

	public static String FeatureSelectionWizardPage_oneOrMoreUnavailable;

	public static String FeatureSelectionWizardPage_provisioningErrorAdvisory;

	public static String FeatureSelectionWizardPage_provisioningWarningAdvisory;

	public static String FeatureSelectionWizardPage_required;

	public static String FeatureSelectionWizardPage_unexpectedException_verifyingFeatures;

	public static String FeatureSelectionWizardPage_Uninstall_Pending;

	public static String FeatureSelectionWizardPage_Update_Pending;

	public static String ImportFavoritesActionLink_errorLoadingFavorites;

	public static String ImportFavoritesActionLink_invalidUrl;

	public static String ImportFavoritesActionLink_noFavoritesFoundAtUrl;

	public static String ImportFavoritesActionLink_noFavoritesFoundForUser;

	public static String ImportFavoritesPage_conflictErrorMessage;

	public static String ImportFavoritesPage_Description;

	public static String ImportFavoritesWizardDialog_FinishButtonLabel;

	public static String ImportFavoritesPage_Title;

	public static String ImportFavoritesPage_unauthorizedErrorMessage;

	public static String ImportFavoritesPage_unknownErrorMessage;

	public static String ItemButtonController_change;

	public static String ItemButtonController_changePending;

	public static String ItemButtonController_install;

	public static String ItemButtonController_installPending;

	public static String ItemButtonController_uninstall;

	public static String ItemButtonController_uninstallPending;

	public static String ItemButtonController_update;

	public static String ItemButtonController_updatePending;

	public static String MarketplaceBrowserIntegration_cannotOpenMarketplaceWizard;

	public static String MarketplaceCatalogConfiguration_invalidStateObject;

	public static String MarketplaceClientService_ExecuteError;

	public static String MarketplaceClientService_noProvisioningOperation;

	public static String MarketplaceDiscoveryResources_LoadImageError;
	public static String MarketplaceDiscoveryResources_FailedCreatingImage;

	public static String MarketplaceDiscoveryResources_retrievingImage;

	public static String MarketplaceDropAdapter_0;

	public static String MarketplacePage_DefaultNewsTitle;

	public static String MarketplacePage_discardPendingSolutions;

	public static String MarketplacePage_eclipseMarketplaceSolutions;

	public static String MarketplacePage_favorites;

	public static String MarketplacePage_featuredMarket;

	public static String MarketplacePage_installed;

	public static String MarketplacePage_linkShowSelection_Multiple;

	public static String MarketplacePage_linkShowSelection_One;

	public static String MarketplacePage_popular;

	public static String MarketplacePage_recent;

	public static String MarketplacePage_related;

	public static String MarketplacePage_search;

	public static String MarketplacePage_selectAlternateCatalog;

	public static String MarketplacePage_selectionSolutions;

	public static String MarketplacePage_selectSolutionsToInstall;

	public static String MarketplacePage_showSelection;

	public static String MarketplacePage_switchCatalog_link;

	public static String MarketplaceViewer_Could_not_change_find_text;

	public static String MarketplaceViewer_featured;

	public static String MarketplaceViewer_go;

	public static String MarketplaceViewer_unexpectedException;

	public static String MarketplaceWizard_cannotOpenUrl;

	public static String MarketplaceWizard_eclipseSolutionCatalogs;

	public static String MarketplaceWizard_errorNotificationJob;

	public static String MarketplaceWizard_IncompatibleSolutionsMessage;

	public static String MarketplaceWizard_problemsPerformingProvisioningOperation;

	public static String MarketplaceWizard_UnableToInstallSolutions;

	public static String MarketplaceWizardDialog_Confirm;

	public static String MarketplaceWizardDialog_Install_More;

	public static String MarketplaceWizardDialog_Install_Now;

	public static String MarketplaceWizardDialog_PromptPendingActionsMessage;

	public static String MarketplaceWizardDialog_PromptPendingActionsTitle;

	public static String NewsViewer_Copy_Link_Address;

	public static String NewsViewer_Loading;

	public static String NewsViewer_No_embeddable_browser;

	public static String NewsViewer_No_news;

	public static String Operation_install;

	public static String Operation_uninstall;

	public static String Operation_unknownOperation;

	public static String Operation_update;

	public static String OverviewToolTip_cannotRenderImage_reason;

	public static String OverviewToolTip_learnMoreLink;

	public static String OverviewToolTip_openUrlInBrowser;

	public static String ProvisioningJobListener_notificationTaskName;

	public static String RatingTooltip_Continue;

	public static String RatingTooltip_Dont_show_again;

	public static String RatingTooltip_Note;

	public static String RetryErrorActionItem_errorDetailsDialogTitle;

	public static String RetryErrorActionItem_failedToLoadMessage;

	public static String RetryErrorActionItem_retryActionLabel;

	public static String RetryErrorActionItem_retryTooltip;

	public static String RetryErrorActionItem_showDetailsActionLabel;

	public static String RetryErrorActionItem_showDetailsTooltip;

	public static String RetryErrorActionItem_unsupportedLinkMessage;

	public static String SelectionModel_cannotInstallRemoveConcurrently;

	public static String SelectionModel_count_selectedFor_operation;

	public static String SelectionModel_countSolutions;

	public static String SelectionModel_countSolutionsSelectedForInstallUpdate;

	public static String SelectionModel_Inconsistent_Actions;

	public static String SelectionModel_Nothing_Selected;

	public static String SelectionModel_oneSolution;

	public static String ShareSolutionLink_CopyToClipboard;

	public static String ShareSolutionLink_EMail;

	public static String ShareSolutionLink_failed_to_open_manually_share;

	public static String ShareSolutionLink_mailSubject;

	public static String ShareSolutionLink_OpenInBrowser;

	public static String ShareSolutionLink_recipient;

	public static String ShareSolutionLink_share;

	public static String ShareSolutionLink_Share;

	public static String ShareSolutionLink_tweet;

	public static String ShareSolutionLink_Tooltip;

	public static String ShareSolutionLink_Twitter;

	public static String UserFavoritesAbstractImportActionItem_importFavoritesActionLabel;

	public static String UserFavoritesAbstractImportActionItem_importFavoritesTooltip;
	public static String UserFavoritesFindFavoritesActionItem_browsePopularActionLabel;

	public static String UserFavoritesFindFavoritesActionItem_browsePopularTooltip;

	public static String UserFavoritesFindFavoritesActionItem_noFavoritesYetMessage;

	public static String UserFavoritesInstallAllActionItem_installAllActionLabel;

	public static String UserFavoritesInstallAllActionItem_installAllTooltip;

	public static String UserFavoritesLoginActionItem_logInActionLabel;

	public static String UserFavoritesUnsupportedActionItem_unsupportedFavoritesLabel;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> mpc-1.5.1.zip: org/eclipse/epp/internal/mpc/ui/wizards/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2010 The Eclipse Foundation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     The Eclipse Foundation - initial API and implementation
 *******************************************************************************/
package org.eclipse.epp.internal.mpc.ui.wizards;

import org.eclipse.osgi.util.NLS;

class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.epp.internal.mpc.ui.wizards.messages"; //$NON-NLS-1$

	public static String BrowseCatalogItem_browseMoreLink;

	public static String BrowseCatalogItem_browseMoreLinkNoCount;

	public static String BrowseCatalogItem_cannotOpenBrowser;

	public static String BrowseCatalogItem_openUrlBrowser;

	public static String CatalogSelectionPage_selectASolutionCatalog;

	public static String CatalogSelectionPage_solutionMarketplaceCatalog;

	public static String CatalogSwitcher_downloadCatalogImage;

	public static String CatalogSwitcher_Header;

	public static String CatalogSwitcher_retrieveMetaData;

	public static String DiscoveryItem_AlreadyInstalled;

	public static String DiscoveryItem_byProviderLicense;

	public static String DiscoveryItem_cannotRenderImage_reason;

	public static String DiscoveryItem_Compact_Number;

	public static String DiscoveryItem_FavoriteActionFailed;

	public static String DiscoveryItem_Favorited_Times;

	public static String DiscoveryItem_installInstructions;

	public static String DiscoveryItem_installInstructionsTooltip;

	public static String DiscoveryItem_Installs;

	public static String DiscoveryItem_missingNodeUrl;

	public static String DiscoveryItem_More_Info;

	public static String DiscoveryItem_Promotion_Display;

	public static String DiscoveryItem_Promotion_Marker;

	public static String DiscoveryItem_Share;

	public static String DiscoveryItem_showOverview;

	public static String DiscoveryItem_truncatedTextSuffix;

	public static String DiscoveryItem_Unknown_Favorites;

	public static String DiscoveryItem_Unknown_Installs;

	public static String DiscoveryItem_UnknownProvider;

	public static String DiscoveryItem_UnnamedSolution;

	public static String FavoritesViewer_searchInputDescription;

	public static String FavoritesViewer_searchLabel;

	public static String FeatureSelectionWizardPage_confirmSelectedFeatures;

	public static String FeatureSelectionWizardPage_confirmSelectedFeatures_description;

	public static String FeatureSelectionWizardPage_details;

	public static String FeatureSelectionWizardPage_detailsUnavailable;

	public static String FeatureSelectionWizardPage_Install_Pending;

	public static String FeatureSelectionWizardPage_noneAvailable;

	public static String FeatureSelectionWizardPage_oneOrMoreUnavailable;

	public static String FeatureSelectionWizardPage_provisioningErrorAdvisory;

	public static String FeatureSelectionWizardPage_provisioningWarningAdvisory;

	public static String FeatureSelectionWizardPage_required;

	public static String FeatureSelectionWizardPage_unexpectedException_verifyingFeatures;

	public static String FeatureSelectionWizardPage_Uninstall_Pending;

	public static String FeatureSelectionWizardPage_Update_Pending;

	public static String ImportFavoritesActionLink_errorLoadingFavorites;

	public static String ImportFavoritesActionLink_invalidUrl;

	public static String ImportFavoritesActionLink_noFavoritesFoundAtUrl;

	public static String ImportFavoritesActionLink_noFavoritesFoundForUser;

	public static String ImportFavoritesPage_conflictErrorMessage;

	public static String ImportFavoritesPage_Description;

	public static String ImportFavoritesWizardDialog_FinishButtonLabel;

	public static String ImportFavoritesPage_Title;

	public static String ImportFavoritesPage_unauthorizedErrorMessage;

	public static String ImportFavoritesPage_unknownErrorMessage;

	public static String ItemButtonController_change;

	public static String ItemButtonController_changePending;

	public static String ItemButtonController_install;

	public static String ItemButtonController_installPending;

	public static String ItemButtonController_uninstall;

	public static String ItemButtonController_uninstallPending;

	public static String ItemButtonController_update;

	public static String ItemButtonController_updatePending;

	public static String MarketplaceBrowserIntegration_cannotOpenMarketplaceWizard;

	public static String MarketplaceCatalogConfiguration_invalidStateObject;

	public static String MarketplaceClientService_ExecuteError;

	public static String MarketplaceClientService_noProvisioningOperation;

	public static String MarketplaceDiscoveryResources_LoadImageError;
	public static String MarketplaceDiscoveryResources_FailedCreatingImage;

	public static String MarketplaceDiscoveryResources_retrievingImage;

	public static String MarketplaceDropAdapter_0;

	public static String MarketplacePage_DefaultNewsTitle;

	public static String MarketplacePage_discardPendingSolutions;

	public static String MarketplacePage_eclipseMarketplaceSolutions;

	public static String MarketplacePage_favorites;

	public static String MarketplacePage_featuredMarket;

	public static String MarketplacePage_installed;

	public static String MarketplacePage_linkShowSelection_Multiple;

	public static String MarketplacePage_linkShowSelection_One;

	public static String MarketplacePage_popular;

	public static String MarketplacePage_recent;

	public static String MarketplacePage_related;

	public static String MarketplacePage_search;

	public static String MarketplacePage_selectAlternateCatalog;

	public static String MarketplacePage_selectionSolutions;

	public static String MarketplacePage_selectSolutionsToInstall;

	public static String MarketplacePage_showSelection;

	public static String MarketplacePage_switchCatalog_link;

	public static String MarketplaceViewer_Could_not_change_find_text;

	public static String MarketplaceViewer_featured;

	public static String MarketplaceViewer_go;

	public static String MarketplaceViewer_unexpectedException;

	public static String MarketplaceWizard_cannotOpenUrl;

	public static String MarketplaceWizard_eclipseSolutionCatalogs;

	public static String MarketplaceWizard_errorNotificationJob;

	public static String MarketplaceWizard_IncompatibleSolutionsMessage;

	public static String MarketplaceWizard_problemsPerformingProvisioningOperation;

	public static String MarketplaceWizard_ProvisioningOperationCancelled;

	public static String MarketplaceWizard_UnableToInstallSolutions;

	public static String MarketplaceWizardDialog_Confirm;

	public static String MarketplaceWizardDialog_Install_More;

	public static String MarketplaceWizardDialog_Install_Now;

	public static String MarketplaceWizardDialog_PromptPendingActionsMessage;

	public static String MarketplaceWizardDialog_PromptPendingActionsTitle;

	public static String NewsViewer_Copy_Link_Address;

	public static String NewsViewer_Loading;

	public static String NewsViewer_No_embeddable_browser;

	public static String NewsViewer_No_news;

	public static String Operation_install;

	public static String Operation_uninstall;

	public static String Operation_unknownOperation;

	public static String Operation_update;

	public static String OverviewToolTip_cannotRenderImage_reason;

	public static String OverviewToolTip_learnMoreLink;

	public static String OverviewToolTip_openUrlInBrowser;

	public static String ProvisioningJobListener_notificationTaskName;

	public static String RatingTooltip_Continue;

	public static String RatingTooltip_Dont_show_again;

	public static String RatingTooltip_Note;

	public static String RetryErrorActionItem_errorDetailsDialogTitle;

	public static String RetryErrorActionItem_failedToLoadMessage;

	public static String RetryErrorActionItem_retryActionLabel;

	public static String RetryErrorActionItem_retryTooltip;

	public static String RetryErrorActionItem_showDetailsActionLabel;

	public static String RetryErrorActionItem_showDetailsTooltip;

	public static String RetryErrorActionItem_unsupportedLinkMessage;

	public static String SelectionModel_cannotInstallRemoveConcurrently;

	public static String SelectionModel_count_selectedFor_operation;

	public static String SelectionModel_countSolutions;

	public static String SelectionModel_countSolutionsSelectedForInstallUpdate;

	public static String SelectionModel_Inconsistent_Actions;

	public static String SelectionModel_Nothing_Selected;

	public static String SelectionModel_oneSolution;

	public static String ShareSolutionLink_CopyToClipboard;

	public static String ShareSolutionLink_EMail;

	public static String ShareSolutionLink_failed_to_open_manually_share;

	public static String ShareSolutionLink_mailSubject;

	public static String ShareSolutionLink_OpenInBrowser;

	public static String ShareSolutionLink_recipient;

	public static String ShareSolutionLink_share;

	public static String ShareSolutionLink_Share;

	public static String ShareSolutionLink_tweet;

	public static String ShareSolutionLink_Tooltip;

	public static String ShareSolutionLink_Twitter;

	public static String UserFavoritesAbstractImportActionItem_importFavoritesActionLabel;

	public static String UserFavoritesAbstractImportActionItem_importFavoritesTooltip;
	public static String UserFavoritesFindFavoritesActionItem_browsePopularActionLabel;

	public static String UserFavoritesFindFavoritesActionItem_browsePopularTooltip;

	public static String UserFavoritesFindFavoritesActionItem_noFavoritesYetMessage;

	public static String UserFavoritesInstallAllActionItem_installAllActionLabel;

	public static String UserFavoritesInstallAllActionItem_installAllTooltip;

	public static String UserFavoritesLoginActionItem_logInActionLabel;

	public static String UserFavoritesLoginActionItem_retryLoginLabel;

	public static String UserFavoritesUnsupportedActionItem_unsupportedFavoritesLabel;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
